# Using Tianocore edk2 pytool library (edk2toollib)

## Installing

NOTE: It is suggested to use python virtual environments to avoid dependency pollution and conflicts. [Read More](https://docs.python.org/3/library/venv.html)

Install from pip

```cmd 
pip install --upgrade edk2-pytool-library
```

## Using in python code

```python
from edk2toollib.<module> import <class>
```
